@@ -3,7 +3,7 @@
 /**
  * Driver for holidays in Germany
  *
- * PHP Version 4
+ * PHP Version 5
  *
  * Copyright (c) 1997-2008 The PHP Group
  *
@@ -19,7 +19,7 @@
  * @package  Date_Holidays
  * @author   Tim Dodge <timmy@invisibles.org>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: EnglandWales.php 320325 2011-12-03 23:03:00Z kguest $
+ * @version  CVS: $Id$
  * @link     http://pear.php.net/package/Date_Holidays
  */
 require_once 'Date/Holidays/Driver/Christian.php';
@@ -32,7 +32,7 @@ require_once 'Date/Holidays/Driver/Christian.php';
  * @subpackage Driver
  * @author     Tim Dodge <timmy@invisibles.org>
  * @license    http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version    CVS: $Id: EnglandWales.php 320325 2011-12-03 23:03:00Z kguest $
+ * @version    CVS: $Id$
  * @link       http://pear.php.net/package/Date_Holidays
  */
 class Date_Holidays_Driver_EnglandWales extends Date_Holidays_Driver
@@ -113,13 +113,6 @@ class Date_Holidays_Driver_EnglandWales extends Date_Holidays_Driver
                            $easterDate->getNextDay(),
                            'Easter Monday');
 
-        /**
-         * Mothers Day
-         */
-        $this->_addHoliday('mothersDay',
-                           $this->_addDays($easterDate, -21),
-                           'Mother\'s Day');
-
         /**
          * May Day Bank Holiday
          */
