@@ -9,14 +9,12 @@
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Date_Holidays_Driver_EnglandWales_TestSuite.php 320325 2011-12-03 23:03:00Z kguest $
+ * @version  CVS: $Id$
  * @link     http://pear.php.net/package/Date_Holidays
  */
-if (!defined("PHPUnit_MAIN_METHOD")) {
-    define("PHPUnit_MAIN_METHOD", "Date_HolidaysTest::main");
-}
 
-require_once 'Date/Holidays.php';
+/** Set up the environment */
+require_once dirname(__FILE__) . '/helper.inc';
 
 /**
  * Test class for running unit tests related to the driver for holidays in
@@ -27,7 +25,7 @@ require_once 'Date/Holidays.php';
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Date_Holidays_Driver_EnglandWales_TestSuite.php 320325 2011-12-03 23:03:00Z kguest $
+ * @version  CVS: $Id$
  * @link     http://pear.php.net/package/Date_Holidays
  */
 class Date_Holidays_Driver_EnglandWales_TestSuite extends PHPUnit_Framework_TestCase
@@ -54,9 +52,6 @@ class Date_Holidays_Driver_EnglandWales_TestSuite extends PHPUnit_Framework_Test
                 'easterMonday' => array('day' => 13,
                     'month' => 4,
                     'year' => 2009),
-                'mothersDay'   => array('day' => 22,
-                    'month' => 3,
-                    'year' => 2009),
                 'mayDay'       => array('day' => 4,
                     'month' => 5,
                     'year' => 2009),
@@ -110,14 +105,15 @@ class Date_Holidays_Driver_EnglandWales_TestSuite extends PHPUnit_Framework_Test
      */
     function testHolidays2009()
     {
-        $drv = Date_Holidays::factory('EnglandWales', 2009, 'en_EN');
-        $this->assertFalse(Date_Holidays::isError($drv));
+        $drv = Date_Holidays::factory('EnglandWales', 2009);
         if (Date_Holidays::isError($drv)) {
-            print_r($drv);
-            die($drv->getMessage());
+            $this->fail(helper_get_error_message($drv));
         }
         foreach ($this->testDates2009 as $name => $dateInfo) {
             $day = $drv->getHoliday($name);
+            if (Date_Holidays::isError($day)) {
+                $this->fail(helper_get_error_message($day));
+            }
             $this->assertFalse(Date_Holidays::isError($day));
             $this->assertEquals($name, $day->getInternalName());
             $date = $day->getDate();
@@ -135,7 +131,7 @@ class Date_Holidays_Driver_EnglandWales_TestSuite extends PHPUnit_Framework_Test
      */
     function testHolidays2010()
     {
-        $drv = Date_Holidays::factory('EnglandWales', 2010, 'en_EN');
+        $drv = Date_Holidays::factory('EnglandWales', 2010);
         $this->assertFalse(Date_Holidays::isError($drv));
         foreach ($this->testDates2010 as $name => $dateInfo) {
             $day = $drv->getHoliday($name);
@@ -157,7 +153,7 @@ class Date_Holidays_Driver_EnglandWales_TestSuite extends PHPUnit_Framework_Test
          * http://direct.gov.uk/en/Employment/Employees/Timeoffandholidays/DG_073741
          */
 
-        $d12 = Date_Holidays::factory('EnglandWales', 2012, 'en_EN');
+        $d12 = Date_Holidays::factory('EnglandWales', 2012);
         $day = $d12->getHoliday('queensJubilee');
         $this->assertEquals(false, Date_Holidays::isError($day));
         $date = $day->getDate();
@@ -171,7 +167,7 @@ class Date_Holidays_Driver_EnglandWales_TestSuite extends PHPUnit_Framework_Test
         $this->assertEquals($sdate->getMonth(), 6);
         $this->assertEquals($sdate->getDay(), 4);
 
-        $d11 = Date_Holidays::factory('EnglandWales', 2011, 'en_EN');
+        $d11 = Date_Holidays::factory('EnglandWales', 2011);
         $day = $d11->getHoliday('queensJubilee');
         $this->assertEquals(true, Date_Holidays::isError($day));
         $this->assertEquals(
@@ -179,6 +175,9 @@ class Date_Holidays_Driver_EnglandWales_TestSuite extends PHPUnit_Framework_Test
             $day->getMessage()
         );
         $sbd = $d11->getHoliday('springBank');
+        if (Date_Holidays::isError($sbd)) {
+            $this->fail(helper_get_error_message($sbd));
+        }
         $sdate = $sbd->getDate();
         $this->assertEquals($sdate->getYear(), 2011);
         $this->assertEquals($sdate->getMonth(), 5);
